# Exercise Basics (DuMuX course)
<br>

## Problem set-up

N$`_2`$ is injected in an aquifer previously saturated with water with an injection rate of 0.0001 kg/(s*m$`^2`$).
The aquifer is situated 2700 m below sea level and the domain size is 60 m x 40 m. It consists of two layers, a moderately permeable one ($`\Omega_1`$) and a lower permeable one ($`\Omega_2`$).

<img src="https://git.iws.uni-stuttgart.de/dumux-repositories/dumux-course/raw/master/exercises/extradoc/exercise1_setup.png" width="1000">

## Preparing the exercise

* Navigate to the directory `dumux-course/exercises/exercise-basic`

This exercise deals with two problems: a two-phase immiscible problem (__2p__) and a two-phase compositional problem (__2p2c__). They both set up the same scenario with the difference that the 2p2c assumes a miscible fluid state for the two fluids (water and gaseous N$`_2`$) and the 2p model assumes an immiscible fluid state.

<br><br>
### Task 1: Getting familiar with the code
<hr>

Locate all the files you will need for this exercise
* The __main file__ for the __2p__ problem : `2pmain.cc`
* The __main file__ for the __2p2c__ problem : `2p2cmain.cc`
* The __problem file__ for the __2p__ problem: `injection2pproblem.hh`
* The __problem file__ for the __2p2c__ problem: `injection2p2cproblem.hh`
* The __properties file__ for the __2p__problem: `properties2p.hh`
* The __properties file__ for the __2p2c__problem: `properties2p2c.hh`
* The shared __spatial parameters file__: `injection2pspatialparams.hh`
* The shared __input file__: `params.input`

<br><br>
### Task 2: Compiling and running an executable
<hr>

* Change to the build-directory

```bash
cd ../../build-cmake/exercises/exercise-basic
```

* Compile both executables `exercise_basic_2p` and `exercise_basic_2p2c`

```bash
make exercise_basic_2p exercise_basic_2p2c
```

* Execute the two problems and inspect the result

```bash
./exercise_basic_2p params.input
./exercise_basic_2p2c params.input
```

* you can look at the results with paraview

```bash
paraview injection-2p2c.pvd
```

<br><br>
### Task 3: Setting up a new executable (for a non-isothermal simulation)
<hr>

* Copy the main file `2pmain.cc` and rename it to `2pnimain.cc`
* In  `2pnimain.cc`, include the header `properties2pni.hh` instead of `properties2p.hh`.
* In  `2pnimain.cc`, change `Injection2pCC` to `Injection2pNICC` in the line `using TypeTag = Properties::TTag::Injection2pNICC;`
* Add a new executable in `CMakeLists.txt` by adding the lines

```cmake
# the two-phase non-isothermal simulation program
dune_add_test(NAME exercise_basic_2pni
              SOURCES 2pnimain.cc)
```

* Test that everything compiles without error

```bash
make # should rerun cmake
make exercise_basic_2pni # builds new executable
```

<br><br>
### Task 4: Setting up a non-isothermal __2pni__ test problem
<hr>

* Open the files `injection2pniproblem.hh` and `properties2pni.hh`.
These are a copies of the `injection2pproblem.hh` `properties2pni.hh` files, with some useful comments on how to implement a non-isothermal model. 
Look for comments containing

```c++
// TODO: dumux-course-task 4
```

* The following set-up should be realized:

  __Boundary conditions:__ Dirichlet conditions at the left boundary. For the primary variable 'temperature' use a varying temperature of <br/>
$`\displaystyle T(y) = 283~\text{K} + 0.03~\frac{\text{K}}{\text{m}} \cdot \left( d_\text{aquifer} - y \right) `$, <br/>
with the aquifer depth
$`\displaystyle d_\text{aquifer}=2700~\text{m}`$.
Assign Neumann no-flow for the energy balance to the rest of the boundaries.

  __Initial conditions:__ The same temperature gradient as in the boundary conditions with an exception in the subdomain (20 < x < 30, 5 < y < 35), where you assign a constant initial temperature of 380 K.

<img src="https://git.iws.uni-stuttgart.de/dumux-repositories/dumux-course/raw/master/exercises/extradoc/exercise1_nonisothermal.png" width="800">

The non-isothermal model requires additional parameters like the thermal conductivity of the solid component. They are already implemented and set in `params.input`, you just need to _uncomment_ them.
